@@ -31,7 +31,10 @@ var corefileTemplate = template.Must(template.New("Corefile").Parse(`{{range .Se
 {{end -}}
 .:5353 {
     errors
-    health
+    health {
+        lameduck 20s
+    }
+    ready
     kubernetes {{.ClusterDomain}} in-addr.arpa ip6.arpa {
         pods insecure
         upstream
